ALTER EXTENSION postgis_tiger_geocoder ADD function count_words(character varying);
ALTER EXTENSION postgis_tiger_geocoder ADD function create_census_base_tables();
ALTER EXTENSION postgis_tiger_geocoder ADD function cull_null(character varying);
ALTER EXTENSION postgis_tiger_geocoder ADD function diff_zip(character varying,character varying);
ALTER EXTENSION postgis_tiger_geocoder ADD function drop_dupe_featnames_generate_script();
ALTER EXTENSION postgis_tiger_geocoder ADD function drop_indexes_generate_script(text);
ALTER EXTENSION postgis_tiger_geocoder ADD function drop_nation_tables_generate_script(text);
ALTER EXTENSION postgis_tiger_geocoder ADD function drop_state_tables_generate_script(text,text);
ALTER EXTENSION postgis_tiger_geocoder ADD function end_soundex(character varying);
ALTER EXTENSION postgis_tiger_geocoder ADD function geocode(character varying,integer,geometry);
ALTER EXTENSION postgis_tiger_geocoder ADD function geocode(norm_addy,integer,geometry);
ALTER EXTENSION postgis_tiger_geocoder ADD function geocode_address(norm_addy,integer,geometry);
ALTER EXTENSION postgis_tiger_geocoder ADD function geocode_intersection(text,text,text,text,text,integer);
ALTER EXTENSION postgis_tiger_geocoder ADD function geocode_location(norm_addy,geometry);
ALTER EXTENSION postgis_tiger_geocoder ADD function get_geocode_setting(text);
ALTER EXTENSION postgis_tiger_geocoder ADD function get_last_words(character varying,integer);
ALTER EXTENSION postgis_tiger_geocoder ADD function get_tract(geometry,text);
ALTER EXTENSION postgis_tiger_geocoder ADD function greatest_hn(character varying,character varying);
ALTER EXTENSION postgis_tiger_geocoder ADD function includes_address(integer,integer,integer,integer,integer);
ALTER EXTENSION postgis_tiger_geocoder ADD function install_geocode_settings();
ALTER EXTENSION postgis_tiger_geocoder ADD function install_missing_indexes();
ALTER EXTENSION postgis_tiger_geocoder ADD function install_pagc_tables();
ALTER EXTENSION postgis_tiger_geocoder ADD function interpolate_from_address(integer,character varying,character varying,geometry,character varying,double precision);
ALTER EXTENSION postgis_tiger_geocoder ADD function is_pretype(text);
ALTER EXTENSION postgis_tiger_geocoder ADD function least_hn(character varying,character varying);
ALTER EXTENSION postgis_tiger_geocoder ADD function levenshtein_ignore_case(character varying,character varying);
ALTER EXTENSION postgis_tiger_geocoder ADD function loader_generate_census_script(text[],text);
ALTER EXTENSION postgis_tiger_geocoder ADD function loader_generate_nation_script(text);
ALTER EXTENSION postgis_tiger_geocoder ADD function loader_generate_script(text[],text);
ALTER EXTENSION postgis_tiger_geocoder ADD function loader_load_staged_data(text,text);
ALTER EXTENSION postgis_tiger_geocoder ADD function loader_load_staged_data(text,text,text[]);
ALTER EXTENSION postgis_tiger_geocoder ADD function loader_macro_replace(text,text[],text[]);
ALTER EXTENSION postgis_tiger_geocoder ADD function location_extract(character varying,character varying);
ALTER EXTENSION postgis_tiger_geocoder ADD function location_extract_countysub_exact(character varying,character varying);
ALTER EXTENSION postgis_tiger_geocoder ADD function location_extract_countysub_fuzzy(character varying,character varying);
ALTER EXTENSION postgis_tiger_geocoder ADD function location_extract_place_exact(character varying,character varying);
ALTER EXTENSION postgis_tiger_geocoder ADD function location_extract_place_fuzzy(character varying,character varying);
ALTER EXTENSION postgis_tiger_geocoder ADD function missing_indexes_generate_script();
ALTER EXTENSION postgis_tiger_geocoder ADD function normalize_address(character varying);
ALTER EXTENSION postgis_tiger_geocoder ADD function nullable_levenshtein(character varying,character varying);
ALTER EXTENSION postgis_tiger_geocoder ADD function numeric_streets_equal(character varying,character varying);
ALTER EXTENSION postgis_tiger_geocoder ADD function pagc_normalize_address(character varying);
ALTER EXTENSION postgis_tiger_geocoder ADD function pprint_addy(norm_addy);
ALTER EXTENSION postgis_tiger_geocoder ADD function rate_attributes(character varying,character varying,character varying,character varying,character varying,character varying,character varying,character varying,character varying);
ALTER EXTENSION postgis_tiger_geocoder ADD function rate_attributes(character varying,character varying,character varying,character varying,character varying,character varying,character varying,character varying,character varying,character varying,character varying);
ALTER EXTENSION postgis_tiger_geocoder ADD function reverse_geocode(geometry,boolean);
ALTER EXTENSION postgis_tiger_geocoder ADD function set_geocode_setting(text,text);
ALTER EXTENSION postgis_tiger_geocoder ADD function setsearchpathforinstall(character varying);
ALTER EXTENSION postgis_tiger_geocoder ADD function state_extract(character varying);
ALTER EXTENSION postgis_tiger_geocoder ADD function topology_load_tiger(character varying,character varying,character varying);
ALTER EXTENSION postgis_tiger_geocoder ADD function utmzone(geometry);
ALTER EXTENSION postgis_tiger_geocoder ADD function zip_range(text,integer,integer);
ALTER EXTENSION postgis_tiger_geocoder ADD sequence addr_gid_seq;
ALTER EXTENSION postgis_tiger_geocoder ADD sequence addrfeat_gid_seq;
ALTER EXTENSION postgis_tiger_geocoder ADD sequence county_gid_seq;
ALTER EXTENSION postgis_tiger_geocoder ADD sequence cousub_gid_seq;
ALTER EXTENSION postgis_tiger_geocoder ADD sequence edges_gid_seq;
ALTER EXTENSION postgis_tiger_geocoder ADD sequence faces_gid_seq;
ALTER EXTENSION postgis_tiger_geocoder ADD sequence featnames_gid_seq;
ALTER EXTENSION postgis_tiger_geocoder ADD sequence pagc_gaz_id_seq;
ALTER EXTENSION postgis_tiger_geocoder ADD sequence pagc_lex_id_seq;
ALTER EXTENSION postgis_tiger_geocoder ADD sequence pagc_rules_id_seq;
ALTER EXTENSION postgis_tiger_geocoder ADD sequence place_gid_seq;
ALTER EXTENSION postgis_tiger_geocoder ADD sequence state_gid_seq;
ALTER EXTENSION postgis_tiger_geocoder ADD sequence zcta5_gid_seq;
ALTER EXTENSION postgis_tiger_geocoder ADD table addr;
ALTER EXTENSION postgis_tiger_geocoder ADD table addrfeat;
ALTER EXTENSION postgis_tiger_geocoder ADD table county;
ALTER EXTENSION postgis_tiger_geocoder ADD table county_lookup;
ALTER EXTENSION postgis_tiger_geocoder ADD table countysub_lookup;
ALTER EXTENSION postgis_tiger_geocoder ADD table cousub;
ALTER EXTENSION postgis_tiger_geocoder ADD table direction_lookup;
ALTER EXTENSION postgis_tiger_geocoder ADD table edges;
ALTER EXTENSION postgis_tiger_geocoder ADD table faces;
ALTER EXTENSION postgis_tiger_geocoder ADD table featnames;
ALTER EXTENSION postgis_tiger_geocoder ADD table geocode_settings;
ALTER EXTENSION postgis_tiger_geocoder ADD table loader_lookuptables;
ALTER EXTENSION postgis_tiger_geocoder ADD table loader_platform;
ALTER EXTENSION postgis_tiger_geocoder ADD table loader_variables;
ALTER EXTENSION postgis_tiger_geocoder ADD table pagc_gaz;
ALTER EXTENSION postgis_tiger_geocoder ADD table pagc_lex;
ALTER EXTENSION postgis_tiger_geocoder ADD table pagc_rules;
ALTER EXTENSION postgis_tiger_geocoder ADD table place;
ALTER EXTENSION postgis_tiger_geocoder ADD table place_lookup;
ALTER EXTENSION postgis_tiger_geocoder ADD table secondary_unit_lookup;
ALTER EXTENSION postgis_tiger_geocoder ADD table state;
ALTER EXTENSION postgis_tiger_geocoder ADD table state_lookup;
ALTER EXTENSION postgis_tiger_geocoder ADD table street_type_lookup;
ALTER EXTENSION postgis_tiger_geocoder ADD table zcta5;
ALTER EXTENSION postgis_tiger_geocoder ADD table zip_lookup;
ALTER EXTENSION postgis_tiger_geocoder ADD table zip_lookup_all;
ALTER EXTENSION postgis_tiger_geocoder ADD table zip_lookup_base;
ALTER EXTENSION postgis_tiger_geocoder ADD table zip_state;
ALTER EXTENSION postgis_tiger_geocoder ADD table zip_state_loc;
ALTER EXTENSION postgis_tiger_geocoder ADD type norm_addy;